Release notes — ASE documentation

### Navigation

- index
- modules |
- ASE development »

# Release notes

## Development version in trunk

trunk.

- ...

## Version 3.9.0

28 May 2015: tags/3.9.0.

- Genetic algorithm implemented; `ase.ga`. This can be used for the optimization of: atomic cluster structure, materials properties by use of template structures. Extension to other projects related to atomic simulations should be straightforward.
- The `ase.lattice.bulk()` function can now build the Wurtzite structure.
- The `ase.utils.timing.Timer` was moved from GPAW to ASE.
- New `ase.db` module.
- New functions: `ase.lattice.surface.fcc211()` and `ase.visualize.mlab.plot()`.
- New `Atoms` methods: `ase.atoms.Atoms.get_distances()` and `ase.atoms.Atoms.get_all_distances()`.
- Bash completion can now be enabled.
- Preliminary support for Python 3.
- Wrapping: new `ase.atoms.Atoms.wrap()` method and `ase.utils.geometry.wrap_positions()` function. Also added `wrap=True` keyword argument to `ase.atoms.Atoms.get_scaled_positions()` that can be used to turn off wrapping.
- New improved method for initializing NEB calculations: `ase.neb.NEB.interpolate()`.
- New pickle-free future-proof trajectory file format added: The TrajectoryReader and TrajectoryWriter objects.
- We can now do Phase diagrams and Pourbaix diagrams.
- New `ase.lattice.surface.mx2()` function for 1T and 2H metal dichalcogenides and friends.
- New `ase.dft.bandgap.get_band_gap()` function
- `CP2K` interface.

## Version 3.8.0

22 October 2013: tags/3.8.0.

- ASE’s `gui` renamed from `ag` to `ase-gui`.
- New STM module.
- Python 2.6 is now a requirement.
- The old `ase.structure.bulk()` function is now deprecated. Use the new one instead (`ase.lattice.bulk()`).
- We’re now using BuildBot for continous integration: https://ase-buildbot.fysik.dtu.dk/waterfall
- New interface to the JDFTx code.

## Version 3.7.0

13 May 2013: tags/3.7.0.

- ASE’s GUI can now be configured to be more friendly to visually impaired users: High contrast settings for ase-gui.
- The `ase.neb.NEB` object now accepts a list of spring constants.
- Important backwards incompatible change: The `ase.lattice.surface.surface()` function now returns a right-handed unit cell.
- Mopac, NWChem and Gaussian interfaces and EAM potential added.
- New `set_initial_charges()` and `get_initial_charges()` methods. The `get_charges()` method will now ask the calculator to calculate the atomic charges.
- The Calculator interface proposal has been implemented and 6 ASE calculators are now based on the new base classes.
- ASE now runs on Windows and Mac.
- Constrained minima hopping (global optimization) added to ASE.

## Version 3.6.0

24 Feb 2012: tags/3.6.0.

- ASE GUI translations added, available: da_DK, en_GB, es_ES.
- New function for making surfaces with arbitrary Miller indices with the smallest possible surface unit cell: ase.lattice.surface.surface()
- New ase.lattice.bulk() function. Will replace old ase.structure.bulk() function. The new one will produce a more natural hcp lattice and it will use experimental data for crystal structure and lattice constants if not provided explicitely.
- New values for ase.data.covalent_radii from Cordeo et al..
- New command line tool: GPAW command line tool and tests based on it: abinit, elk, fleur, nwchem.
- New crystal builder for ase-gui
- Van der Waals radii in ase.data
- ASE’s GUI (ase-gui) now supports velocities for both graphs and coloring
- Cleaned up some name-spaces:
  - `ase` now contains only `Atoms` and `Atom`
  - `ase.calculators` is now empty

## Version 3.5.1

24 May 2011: tags/3.5.1.

- Problem with parallel vibration calculations fixed: Ticket #80.

## Version 3.5.0

13 April 2011: tags/3.5.0.

- Improved EMT potential: uses a `NeighborList` object and is now ASAP compatible.
- `BFGSLineSearch` is now the default (`QuasiNewton==BFGSLineSearch`).
- There is a new interface to the LAMMPS molecular dynamics code.
- New `phonons` module.
- Van der Waals corrections for DFT, see GPAW usage.
- New `BundleTrajectory` added.
- Updated GUI interface:
  - Stability and usability improvements.
  - Povray render facility.
  - Updated expert user mode.
  - Enabled customization of colours and atomic radii.
  - Enabled user default settings via `~/.ase/gui.py`.
- `Database library` expanded to include:
  - The s22, s26 and s22x5 sets of van der Waals bonded dimers and complexes by the Hobza group.
  - The DBH24 set of gas-phase reaction barrier heights by the Truhlar group.
- Implementation of the Dimer method.

## Version 3.4.1

11 August 2010: tags/3.4.1.

### Navigation

- index
- modules |
- ASE development »